Coverage for C:\src\imod-python\imod\wq\mal.py: 90%

1 from imod.wq.pkgbase import BoundaryCondition

2

3

4 class MassLoading(BoundaryCondition):

5 """

6 Mass loading package. Has no direct effect on groundwater flow, is only

7 included via MT3DMS source and sinks. (SSM ITYPE 15)

8

9 Parameters

10 ----------

11 concentration: xr.DataArray of floats

12 """

13

14 _pkg_id = "mal"

15

16 def __init__(self, concentration):

17 super().__init__()

18 self["concentration"] = concentration

19

20 def repeat_stress(self, concentration, use_cftime=False):

21 self._repeat_stress("concentration", concentration, use_cftime)

22

23 def _pkgcheck(self, ibound=None):

24 self._check_positive(["concentration"])